class BaseConfig():
    # Unleash
    UNLEASH_URL = "https://app.unleash-hosted.com/demo/api"
    UNLEASH_APP_NAME = "pyIvan"
    UNLEASH_ENVIRONMENT = "staging"
    UNLEASH_CUSTOM_HEADERS = {'Authorization': '56907a2fa53c1d16101d509a10b78e36190b0f918d9f122d'}

    # Logging
    LOG_LEVEL = "DEBUG"
    LOG_FORMATTER = "TEXT"


def config_flask(app):
    app.config.from_object(BaseConfig())



import logging
from flask import Blueprint, jsonify, make_response, request
from demo_app.helpers.requestid import requestid
from demo_app.extensions.unleash import UNLEASH

check_blueprint = Blueprint('status', __name__, url_prefix='/check')  # pylint: disable=C0103


FLAG_BANE = 'ivantest'


@requestid
@check_blueprint.route('', methods=['GET'])
def check():
    context = {
        'userId': request.args.get('userId')
    }

    flag_value = UNLEASH.client.is_enabled(FLAG_BANE, context)
    logging.debug(f"Got feature flag value of: {flag_value}")

    return make_response(jsonify(f'Hello, World! Your feature flag is: {flag_value}'), 200)



import sys

import logging
from demo_app.helpers.requestid import RequestIdFilter


def init_app(app):
    # pylint: disable=protected-access
    log_level = logging._nameToLevel[app.config['LOG_LEVEL']]
    log_type = app.config['LOG_FORMATTER']

    # Configure JSON filesystem log handler
    handler = logging.StreamHandler(sys.stdout)

    #pylint: disable=line-too-long
    text_formatter = logging.Formatter('%(asctime)s - %(request_id)s - %(name)s - %(filename)s - %(levelname)s - %(message)s')
    handler.setFormatter(text_formatter)

    handler.addFilter(RequestIdFilter())

    # Configure global logging
    logger = logging.getLogger()
    logger.addHandler(handler)
    logger.setLevel(log_level)

    # app.logger.addHandler(handler)
    # app.logger.setLevel(log_level)